==> konclude_0.6.2+966~dfsg.orig.tar.xz: Konclude-0.6.2-966/Source/Reasoner/Answerer/CAnsweringMessageDataRequirementCompleted.h <==
/*
 *		Copyright (C) 2013-2015, 2019 by the Konclude Developer Team.
 *
 *		This file is part of the reasoning system Konclude.
 *		For details and support, see <http://konclude.com/>.
 *
 *		Konclude is free software: you can redistribute it and/or modify
 *		it under the terms of version 3 of the GNU Lesser General Public
 *		License (LGPLv3) as published by the Free Software Foundation.
 *
 *		Konclude is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *		GNU (Lesser) General Public License for more details.
 *
 *		You should have received a copy of the GNU (Lesser) General Public
 *		License along with Konclude. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef KONCLUDE_REASONER_ANSWERER_CANSWERINGMESSAGEDATAREQUIREMENTCOMPLETED_H
#define KONCLUDE_REASONER_ANSWERER_CANSWERINGMESSAGEDATAREQUIREMENTCOMPLETED_H

// Libraries includes


// Namespace includes
#include "AnswererSettings.h"
#include "CAnsweringMessageData.h"


// Other includes
#include "Reasoner/Ontology/COntologyProcessingDynamicRealizationRequirement.h"


// Logger includes
#include "Logger/CLogger.h"


namespace Konclude {

	namespace Reasoner {

		using namespace Ontology;

		namespace Answerer {


			/*! 
			 *
			 *		\class		CAnsweringMessageDataRequirementCompleted
			 *		\author		Andreas Steigmiller
			 *		\version	0.1
			 *		\brief		TODO
			 *
			 */
			class CAnsweringMessageDataRequirementCompleted : public CAnsweringMessageData {
				// public methods
				public:
					//! Constructor
					enum REQUIREMENTTYPE {
						REALIZATIONREQUIREMENT, CONCEPTASSERTIONENTAILMENTREQUIREMENT, ROLEASSERTIONENTAILMENTREQUIREMENT, ROLETARGETSREALIZATIONREQUIREMENT, SUBCLASSREALIZATIONREQUIREMENT, SUBQUERYANSWERINGREQUIREMENT
					};


					CAnsweringMessageDataRequirementCompleted(REQUIREMENTTYPE requirementType);

					
					REQUIREMENTTYPE getRequirementType();


				// protected methods
				protected:

				// protected variables
				protected:
					REQUIREMENTTYPE mRequirementType;


				// private methods
				private:

				// private variables
				private:

			};

		}; // end namespace Answerer

	}; // end namespace Reasoner

}; // end namespace Konclude

#endif // KONCLUDE_REASONER_ANSWERER_CANSWERINGMESSAGEDATAREQUIREMENTCOMPLETED_H

==> konclude_0.7.0+1137~dfsg.orig.tar.xz: Konclude-0.7.0-1137/Source/Reasoner/Answerer/CAnsweringMessageDataRequirementCompleted.h <==
/*
 *		Copyright (C) 2013-2015, 2019 by the Konclude Developer Team.
 *
 *		This file is part of the reasoning system Konclude.
 *		For details and support, see <http://konclude.com/>.
 *
 *		Konclude is free software: you can redistribute it and/or modify
 *		it under the terms of version 3 of the GNU Lesser General Public
 *		License (LGPLv3) as published by the Free Software Foundation.
 *
 *		Konclude is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *		GNU (Lesser) General Public License for more details.
 *
 *		You should have received a copy of the GNU (Lesser) General Public
 *		License along with Konclude. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef KONCLUDE_REASONER_ANSWERER_CANSWERINGMESSAGEDATAREQUIREMENTCOMPLETED_H
#define KONCLUDE_REASONER_ANSWERER_CANSWERINGMESSAGEDATAREQUIREMENTCOMPLETED_H

// Libraries includes


// Namespace includes
#include "AnswererSettings.h"
#include "CAnsweringMessageData.h"


// Other includes
#include "Reasoner/Ontology/COntologyProcessingDynamicRealizationRequirement.h"


// Logger includes
#include "Logger/CLogger.h"


namespace Konclude {

	namespace Reasoner {

		using namespace Ontology;

		namespace Answerer {


			/*! 
			 *
			 *		\class		CAnsweringMessageDataRequirementCompleted
			 *		\author		Andreas Steigmiller
			 *		\version	0.1
			 *		\brief		TODO
			 *
			 */
			class CAnsweringMessageDataRequirementCompleted : public CAnsweringMessageData {
				// public methods
				public:
					//! Constructor
					enum REQUIREMENTTYPE {
						REALIZATIONREQUIREMENT, CONCEPTASSERTIONENTAILMENTREQUIREMENT, ROLEASSERTIONENTAILMENTREQUIREMENT, ROLETARGETSREALIZATIONREQUIREMENT, SUBCLASSREALIZATIONREQUIREMENT, SUBQUERYANSWERINGREQUIREMENT,
						SUBCLASSAXIOMENTAILMENTREQUIREMENT
					};


					CAnsweringMessageDataRequirementCompleted(REQUIREMENTTYPE requirementType);

					
					REQUIREMENTTYPE getRequirementType();


				// protected methods
				protected:

				// protected variables
				protected:
					REQUIREMENTTYPE mRequirementType;


				// private methods
				private:

				// private variables
				private:

			};

		}; // end namespace Answerer

	}; // end namespace Reasoner

}; // end namespace Konclude

#endif // KONCLUDE_REASONER_ANSWERER_CANSWERINGMESSAGEDATAREQUIREMENTCOMPLETED_H
